pub enum Event {
CPUCycles,
Instructions,
CacheReferences,
CacheMisses,
BranchInstructions,
BranchMisses,
ContextSwitches,
}Variants
CPUCycles
Total cycles.
Instructions
Retired instructions. Be careful, these can be affected by various issues, most notably hardware interrupt counts.
CacheReferences
Cache accesses. Usually this indicates Last Level Cache accesses but this may vary depending on your CPU. This may include prefetches and coherency messages; again this depends on the design of your CPU.
CacheMisses
Cache misses. Usually this indicates Last Level Cache misses; this is intended to be used in conjunction with the [CacheReferences] event to calculate cache miss rates.
BranchInstructions
Retired branch instructions. Prior to Linux 2.6.34, this used the wrong event on AMD processors.
BranchMisses
Mispredicted branch instructions.
ContextSwitches
This counts context switches.